@@ -18,6 +18,7 @@ extern crate serde_json;
 pub use rbatis_core as core;
 pub use rbatis_sql::{expr, push_index, rb_html, rb_py, sql_index};
 pub use rbatis_sql::ops::*;
+pub use rbatis_core::*;
 
 pub use rbatis_macro_driver::{crud_table, CRUDTable, html_sql, py_sql, sql};
 
@@ -26,6 +27,7 @@ pub use crate::core::{convert::StmtConvert, db::DriverType, error::Error, error:
 
 pub mod crud;
 pub mod plugin;
+pub use plugin::*;
 pub mod rbatis;
 pub mod sql;
 #[macro_use]
